==> zio-aws-amplifybackend_3-5.17.104.11-sources.jar: zio/aws/amplifybackend/model/DeleteBackendRequest.scala <==
package zio.aws.amplifybackend.model
import zio.aws.amplifybackend.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeleteBackendRequest(
    appId: __string,
    backendEnvironmentName: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifybackend.model.DeleteBackendRequest = {
    import DeleteBackendRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifybackend.model.DeleteBackendRequest
      .builder()
      .appId(__string.unwrap(appId): java.lang.String)
      .backendEnvironmentName(
        __string.unwrap(backendEnvironmentName): java.lang.String
      )
      .build()
  }
  def asReadOnly: zio.aws.amplifybackend.model.DeleteBackendRequest.ReadOnly =
    zio.aws.amplifybackend.model.DeleteBackendRequest.wrap(buildAwsValue())
}
object DeleteBackendRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifybackend.model.DeleteBackendRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifybackend.model.DeleteBackendRequest =
      zio.aws.amplifybackend.model
        .DeleteBackendRequest(appId, backendEnvironmentName)
    def appId: __string
    def backendEnvironmentName: __string
    def getAppId: ZIO[Any, Nothing, __string] = ZIO.succeed(appId)
    def getBackendEnvironmentName: ZIO[Any, Nothing, __string] =
      ZIO.succeed(backendEnvironmentName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifybackend.model.DeleteBackendRequest
  ) extends zio.aws.amplifybackend.model.DeleteBackendRequest.ReadOnly {
    override val appId: __string =
      zio.aws.amplifybackend.model.primitives.__string(impl.appId())
    override val backendEnvironmentName: __string =
      zio.aws.amplifybackend.model.primitives
        .__string(impl.backendEnvironmentName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifybackend.model.DeleteBackendRequest
  ): zio.aws.amplifybackend.model.DeleteBackendRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-amplifybackend_3-5.17.206.1-sources.jar: zio/aws/amplifybackend/model/DeleteBackendRequest.scala <==
package zio.aws.amplifybackend.model
import zio.aws.amplifybackend.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeleteBackendRequest(
    appId: __string,
    backendEnvironmentName: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifybackend.model.DeleteBackendRequest = {
    import DeleteBackendRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifybackend.model.DeleteBackendRequest
      .builder()
      .appId(appId: java.lang.String)
      .backendEnvironmentName(backendEnvironmentName: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.amplifybackend.model.DeleteBackendRequest.ReadOnly =
    zio.aws.amplifybackend.model.DeleteBackendRequest.wrap(buildAwsValue())
}
object DeleteBackendRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifybackend.model.DeleteBackendRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifybackend.model.DeleteBackendRequest =
      zio.aws.amplifybackend.model
        .DeleteBackendRequest(appId, backendEnvironmentName)
    def appId: __string
    def backendEnvironmentName: __string
    def getAppId: ZIO[Any, Nothing, __string] = ZIO.succeed(appId)
    def getBackendEnvironmentName: ZIO[Any, Nothing, __string] =
      ZIO.succeed(backendEnvironmentName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifybackend.model.DeleteBackendRequest
  ) extends zio.aws.amplifybackend.model.DeleteBackendRequest.ReadOnly {
    override val appId: __string = impl.appId(): __string
    override val backendEnvironmentName: __string =
      impl.backendEnvironmentName(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifybackend.model.DeleteBackendRequest
  ): zio.aws.amplifybackend.model.DeleteBackendRequest.ReadOnly = new Wrapper(
    impl
  )
}
